@@ -449,4 +449,24 @@ class Object:
             return merged
         
         return self
-        
\ No newline at end of file
+        
+    
+    def __getstate__(self):
+        """
+        __getstate__ is used to get the state of the object.
+        It is used for pickle to be able to pickle objects.
+
+        OUT: The self.value
+        """
+        return self.value
+    
+
+    def __setstate__(self, state):
+        """
+        __setstate__ is used to set the state of the object.
+        It is used for pickle to be able to unpickle pickled objects.
+
+        IM: state - The value that should be the objects value
+        """
+        self.__init__()
+        self.value = state
\ No newline at end of file
