@@ -5,7 +5,6 @@ class ApplierLanguage(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/applier-languages'
     
     
@@ -17,10 +16,10 @@ class ApplierLanguage(v1Object):
         """
 
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             self.value = self.value['applierLanguage']
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['assessment']
 
         return self
@@ -31,7 +30,7 @@ class ApplierLanguage(v1Object):
         To post the updates that have been made.
         """
         
-        response_json = self._client.post('aih', 'api/v1/applier-languages/', self.value)
+        response_json = self._client._post('aih', 'api/v1/applier-languages/', self.value)
         self.value['id'] = response_json['applierLanguage']['id']
         
         return self
\ No newline at end of file
