@@ -5,7 +5,6 @@ class Deviation(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/deviation'
         
     
@@ -16,9 +15,9 @@ class Deviation(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['deviations']
         
         return self
@@ -28,7 +27,7 @@ class Deviation(v1Object):
         To post the updates that have been made to self.value
         """
         
-        response_json = self._client.post(self._api, self._endpoint, self.value)
+        response_json = self._client._post(self._api, self._endpoint, self.value)
         self.value['id'] = response_json['deviation']['id']
         
         return self
