@@ -7,7 +7,6 @@ class Media(v1Object):
     
     def __init__(self):
         super().__init__()
-        self._api = 'aih'
         self._endpoint = 'api/v1/media'
         self._valid_filetypes = ['image', 'document']
     
@@ -19,10 +18,10 @@ class Media(v1Object):
         """
         
         if id:
-            self.value = self._client.get(self._api, f'{self._endpoint}/{id}')
+            self.value = self._client._get(self._api, f'{self._endpoint}/{id}')
             self.value = self.value['mediaItem']
         else:
-            self.value = self._client.get(self._api, self._endpoint)
+            self.value = self._client._get(self._api, self._endpoint)
             self.value = self.value['mediaItems']
         
         return self
@@ -43,7 +42,7 @@ class Media(v1Object):
             if not name:
                 name = self.value['name']
         
-            content = self._client.download_media(filetype, name)
+            content = self._client._download_media(filetype, name)
             
             if filetype == 'image':
                 file = Image.open(io.BytesIO(content))
@@ -59,7 +58,7 @@ class Media(v1Object):
                 filetype = media['container']
                 name = media['name']
                 
-                content = self._client.download_media(filetype, name)
+                content = self._client._download_media(filetype, name)
                 
                 if filetype == 'image':
                     file = Image.open(io.BytesIO(content))
@@ -96,7 +95,7 @@ class Media(v1Object):
         else:
             raise AIHE.AIHException(f'filetype was {filetype}, but must be one of the following {self._valid_filetypes}')
         
-        response_json = self._client.upload_media(filetype, _file, name)
+        response_json = self._client._upload_media(filetype, _file, name)
         self.value = response_json['mediaItem']
         
         return self
